aboutsummaryrefslogtreecommitdiffstats
path: root/repository/git.go
diff options
context:
space:
mode:
authorMichael Muré <batolettre@gmail.com>2020-06-27 22:05:45 +0200
committerGitHub <noreply@github.com>2020-06-27 22:05:45 +0200
commit23228101a2a38a139f6fc2cafc18e9f08d911089 (patch)
treeb6f73782f2f400a89fe0a777502a98fe505a080b /repository/git.go
parent1e3dd82fd619f7b43b3193016232ef69f9707f42 (diff)
parent939bcd57b9446b9dce78d7a8c3b15fa13e6320f7 (diff)
downloadgit-bug-23228101a2a38a139f6fc2cafc18e9f08d911089.tar.gz
Merge pull request #413 from MichaelMure/repo-more-tests
repo: more tests
Diffstat (limited to 'repository/git.go')
-rw-r--r--repository/git.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/repository/git.go b/repository/git.go
index e4cb57e6..83037307 100644
--- a/repository/git.go
+++ b/repository/git.go
@@ -337,8 +337,8 @@ func (repo *GitRepo) ListCommits(ref string) ([]git.Hash, error) {
}
-// ListEntries will return the list of entries in a Git tree
-func (repo *GitRepo) ListEntries(hash git.Hash) ([]TreeEntry, error) {
+// ReadTree will return the list of entries in a Git tree
+func (repo *GitRepo) ReadTree(hash git.Hash) ([]TreeEntry, error) {
stdout, err := repo.runGitCommand("ls-tree", string(hash))
if err != nil {